==> zio-aws-mediatailor_3-5.17.124.3-sources.jar: zio/aws/mediatailor/model/GetPlaybackConfigurationRequest.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class GetPlaybackConfigurationRequest(name: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.GetPlaybackConfigurationRequest = {
    import GetPlaybackConfigurationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.GetPlaybackConfigurationRequest
      .builder()
      .name(__string.unwrap(name): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.mediatailor.model.GetPlaybackConfigurationRequest.ReadOnly =
    zio.aws.mediatailor.model.GetPlaybackConfigurationRequest
      .wrap(buildAwsValue())
}
object GetPlaybackConfigurationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.GetPlaybackConfigurationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.GetPlaybackConfigurationRequest =
      zio.aws.mediatailor.model.GetPlaybackConfigurationRequest(name)
    def name: __string
    def getName: ZIO[Any, Nothing, __string] = ZIO.succeed(name)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.GetPlaybackConfigurationRequest
  ) extends zio.aws.mediatailor.model.GetPlaybackConfigurationRequest.ReadOnly {
    override val name: __string =
      zio.aws.mediatailor.model.primitives.__string(impl.name())
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.GetPlaybackConfigurationRequest
  ): zio.aws.mediatailor.model.GetPlaybackConfigurationRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-mediatailor_3-5.17.190.2-sources.jar: zio/aws/mediatailor/model/GetPlaybackConfigurationRequest.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class GetPlaybackConfigurationRequest(name: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.GetPlaybackConfigurationRequest = {
    import GetPlaybackConfigurationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.GetPlaybackConfigurationRequest
      .builder()
      .name(name: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.mediatailor.model.GetPlaybackConfigurationRequest.ReadOnly =
    zio.aws.mediatailor.model.GetPlaybackConfigurationRequest
      .wrap(buildAwsValue())
}
object GetPlaybackConfigurationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.GetPlaybackConfigurationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.GetPlaybackConfigurationRequest =
      zio.aws.mediatailor.model.GetPlaybackConfigurationRequest(name)
    def name: __string
    def getName: ZIO[Any, Nothing, __string] = ZIO.succeed(name)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.GetPlaybackConfigurationRequest
  ) extends zio.aws.mediatailor.model.GetPlaybackConfigurationRequest.ReadOnly {
    override val name: __string = impl.name(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.GetPlaybackConfigurationRequest
  ): zio.aws.mediatailor.model.GetPlaybackConfigurationRequest.ReadOnly =
    new Wrapper(impl)
}
